==> vehicle_form_validator-0.5.0.tar.gz: vehicle_form_validator-0.5.0/README.md <==
# Vehicle Form Validation Library

The library allows you to validate your form inputs using OOPS principles. It has cutomized fields like vehicle make, vehicle type etc also it provides liscence validations specific to country. In addtion to vehicles it provides user details validations.


## Installation

Install the library with:
pip install vehicle_form_validator

## USAGE

from vehicle_form_validator import FieldValidator

# Vehicle Type Validation
vehicle_type = "Car"
if FieldValidator.validate_vehicle_type(vehicle_type):
    print(f"'{vehicle_type}' is a valid vehicle type.")
else:
    print(f"'{vehicle_type}' is an invalid vehicle type.")

# Vehicle Make Validation
vehicle_make = "Toyota"
if FieldValidator.validate_vehicle_make(vehicle_make):
    print(f"'{vehicle_make}' is a valid vehicle make.")
else:
    print(f"'{vehicle_make}' is an invalid vehicle make.")

# License Plate Validation (Ireland)
license_plate = "12-34ABC"
if FieldValidator.validate_license_plate(license_plate, country_code="IE"):
    print(f"'{license_plate}' is a valid license plate for Ireland.")
else:
    print(f"'{license_plate}' is an invalid license plate for Ireland.")

# Phone Number Validation (Ireland)
phone_number = "+353123456789"
if FieldValidator.validate_phone_number(phone_number, country_code="IE"):
    print(f"'{phone_number}' is a valid Irish phone number.")
else:
    print(f"'{phone_number}' is an invalid Irish phone number.")

# Email Validation
email = "test@example.com"
if FieldValidator.validate_email(email):
    print(f"'{email}' is a valid email address.")
else:
    print(f"'{email}' is an invalid email address.")

# Password Validation
password = "Password123!"
confirm_password = "Password123!"
valid, message = FieldValidator.validate_password(password, confirm_password)
if valid:
    print("Password is valid.")
else:
    print(f"Password is invalid: {message}")

# Full Name Validation
full_name = "John Doe"
if FieldValidator.validate_full_name(full_name):
    print(f"'{full_name}' is a valid full name.")
else:
    print(f"'{full_name}' is an invalid full name.")

==> vehicle_form_validator-1.0.0.tar.gz: vehicle_form_validator-1.0.0/README.md <==
# Vehicle Form Validation Library

The library allows you to validate your form inputs using OOPS principles. It has cutomized fields like vehicle make, vehicle type etc also it provides liscence validations specific to country. In addtion to vehicles it provides user details validations.


## Installation

Install the library with:
pip install vehicle_form_validator

## USAGE

from vehicle_form_validator import FieldValidator

# Vehicle Number Validation
vehicle_number = "AB-07-8746"
if FieldValidator.validate_vehicle_number(vehicle_number):
    print(f"'{vehicle_number}' is a valid vehicle number.")
else:
    print(f"'{vehicle_number}' is an invalid vehicle number.")

# Vehicle Type Validation
vehicle_type = "Car"
if FieldValidator.validate_vehicle_type(vehicle_type):
    print(f"'{vehicle_type}' is a valid vehicle type.")
else:
    print(f"'{vehicle_type}' is an invalid vehicle type.")

# Vehicle Make Validation
vehicle_make = "Mahindra"
if FieldValidator.validate_vehicle_make(vehicle_make):
    print(f"'{vehicle_make}' is a valid vehicle make.")
else:
    print(f"'{vehicle_make}' is an invalid vehicle make.")

# Vehicle Model Validation
vehicle_model = "XUV 700"
if FieldValidator.validate_vehicle_model(vehicle_model):
    print(f"'{vehicle_model}' is a valid vehicle model.")
else:
    print(f"'{vehicle_model}' is an invalid vehicle model.")

# License Plate Validation (Ireland)
license_plate = "12-34ABC"
if FieldValidator.validate_license_plate(license_plate, country_code="IE"):
    print(f"'{license_plate}' is a valid license plate for Ireland.")
else:
    print(f"'{license_plate}' is an invalid license plate for Ireland.")

# Phone Number Validation (Ireland)
phone_number = "+353123456789"
if FieldValidator.validate_phone_number(phone_number, country_code="IE"):
    print(f"'{phone_number}' is a valid Irish phone number.")
else:
    print(f"'{phone_number}' is an invalid Irish phone number.")

# Email Validation
email = "test@example.com"
if FieldValidator.validate_email(email):
    print(f"'{email}' is a valid email address.")
else:
    print(f"'{email}' is an invalid email address.")

# Password Validation
password = "Password123!"
confirm_password = "Password123!"
valid, message = FieldValidator.validate_password(password, confirm_password)
if valid:
    print("Password is valid.")
else:
    print(f"Password is invalid: {message}")

# Full Name Validation
full_name = "John Doe"
if FieldValidator.validate_full_name(full_name):
    print(f"'{full_name}' is a valid full name.")
else:
    print(f"'{full_name}' is an invalid full name.")
